@@ -59,6 +59,7 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
 
         super(IotRedisSubscriber, self).__init__()
         self.daemon = True
+        self.force_disconnection = False
         self.data_list = queue.Queue()
         self.init_channels = list(channels_to_consume)
         if 'func_handler' in kwargs:
@@ -77,7 +78,7 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
 
         # Subscribe
         self._subscribe_channels(*self.init_channels)
-        while True:
+        while not self.force_disconnection:
             try:
                 self.pubsub.ping()
                 self.listen()
@@ -145,6 +146,9 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
         except queue.Empty as _:
             return
 
+    def shutdown_listen(self):
+        self.force_disconnection = True
+
 
 class IotRedisPublisher(IotRedisBasic):
     def __init__(self, *args, **kwargs):
